#include <ubb/ubb.h>
#include <stdio.h>

/* Pin assignments:
 *
 * Sniffer  UBB   Shield
 * -------  ----  ------
 * DAT2     DAT2      11 (MOSI)
 * CD       DAT3      12 (MISO)
 * CMD      CMD        7 (RESET)
 * VCC      VDD      VIN
 * CLK      CLK       13 (SCLK)
 * GND      GND      GND
 * DAT0     DAT0       9 (INT)
 * DAT1     DAT1      10 (SS)
 *                     8 (GPX) (not assigned)
 */

#define MAX_RESET UBB_CMD
#define MAX_SCLK  UBB_CLK
#define MAX_INT   UBB_DAT0
#define MAX_SS    UBB_DAT1
#define MAX_MOSI  UBB_DAT2
#define MAX_MISO  UBB_DAT3

int main(int argc, char *argv[])
{
    if (ubb_open(0) < 0) {
        perror("ubb_open");
        return 1;
    }

    ubb_power(1);
    printf("Power on.\n");
    getchar();

    OUT(MAX_RESET);
    OUT(MAX_SCLK);
    OUT(MAX_INT);
    OUT(MAX_SS);
    OUT(MAX_MOSI);
    OUT(MAX_MISO);

    printf("RESET...");
    getchar();
    printf("SET");
    SET(MAX_RESET);
    getchar();
    printf("CLR");
    CLR(MAX_RESET);
    getchar();

    printf("SCLK...");
    getchar();
    printf("SET");
    SET(MAX_SCLK);
    getchar();
    printf("CLR");
    CLR(MAX_SCLK);
    getchar();

    printf("INT...");
    getchar();
    printf("SET");
    SET(MAX_INT);
    getchar();
    printf("CLR");
    CLR(MAX_INT);
    getchar();

    printf("SS...");
    getchar();
    printf("SET");
    SET(MAX_SS);
    getchar();
    printf("CLR");
    CLR(MAX_SS);
    getchar();

    printf("MOSI...");
    getchar();
    printf("SET");
    SET(MAX_MOSI);
    getchar();
    printf("CLR");
    CLR(MAX_MOSI);
    getchar();

    printf("MISO...");
    getchar();
    printf("SET");
    SET(MAX_MISO);
    getchar();
    printf("CLR");
    CLR(MAX_MISO);
    getchar();

    printf("Closing...\n");
    ubb_close(0);

    return 0;
}
